TangoDataType

Enum TangoDataType 

pub enum TangoDataType {
Show 29 variants Void = 0, Boolean = 1, Short = 2, Long = 3, Float = 4, Double = 5, UShort = 6, ULong = 7, String = 8, CharArray = 9, ShortArray = 10, LongArray = 11, FloatArray = 12, DoubleArray = 13, UShortArray = 14, ULongArray = 15, StringArray = 16, LongStringArray = 17, DoubleStringArray = 18, State = 19, ConstString = 20, BooleanArray = 21, UChar = 22, Long64 = 23, ULong64 = 24, Long64Array = 25, ULong64Array = 26, Int = 27, Encoded = 28,
}
The type of a Tango command argument/result, attribute data, or property value.

Not all types can be used for all of the three! For example, LongStringArray is only valid as a command argument or result.

Variants



Void = 0



Boolean = 1



Short = 2



Long = 3



Float = 4



Double = 5



UShort = 6



ULong = 7



String = 8



CharArray = 9



ShortArray = 10



LongArray = 11



FloatArray = 12



DoubleArray = 13



UShortArray = 14



ULongArray = 15



StringArray = 16



LongStringArray = 17



DoubleStringArray = 18



State = 19



ConstString = 20



BooleanArray = 21



UChar = 22



Long64 = 23



ULong64 = 24



Long64Array = 25



ULong64Array = 26



Int = 27



Encoded = 28