Enum tango_client::types::CommandData [−][src]
pub enum CommandData {
Show 26 variants
Void,
Boolean(bool),
Short(i16),
UShort(u16),
Long(i32),
ULong(u32),
Long64(i64),
ULong64(u64),
Float(f32),
Double(f64),
String(Vec<u8>),
State(TangoDevState),
Encoded(DevEncoded),
BooleanArray(Vec<bool>),
CharArray(Vec<u8>),
ShortArray(Vec<i16>),
UShortArray(Vec<u16>),
LongArray(Vec<i32>),
ULongArray(Vec<u32>),
Long64Array(Vec<i64>),
ULong64Array(Vec<u64>),
FloatArray(Vec<f32>),
DoubleArray(Vec<f64>),
StringArray(Vec<Vec<u8>>),
LongStringArray(Vec<i32>, Vec<Vec<u8>>),
DoubleStringArray(Vec<f64>, Vec<Vec<u8>>),
}Expand description
Represents the input or output arguments of a command.
The normal way to construct this is to use the desired variant directly.
Variants
Boolean(bool)Tuple Fields of Boolean
0: boolShort(i16)Tuple Fields of Short
0: i16UShort(u16)Tuple Fields of UShort
0: u16Long(i32)Tuple Fields of Long
0: i32ULong(u32)Tuple Fields of ULong
0: u32Long64(i64)Tuple Fields of Long64
0: i64ULong64(u64)Tuple Fields of ULong64
0: u64Float(f32)Tuple Fields of Float
0: f32Double(f64)Tuple Fields of Double
0: f64State(TangoDevState)Tuple Fields of State
Encoded(DevEncoded)Tuple Fields of Encoded
0: DevEncodedImplementations
Try to convert this data into a different type.
If the conversion fails or is impossible, Self is returned unchanged
in the Err variant.
Return the value if it’s a bool or integral 0 or 1. Otherwise return
Err(self).
Return the value as i32 if it’s an integral type and inside i32 limits.
Otherwise return Err(self).
Return the value as i64 if it’s a an integral type and inside i64
limits. Otherwise return Err(self).
Return the value as u32 if it’s an integral type and inside u32 limits.
Otherwise return Err(self).
Return the value as u64 if it’s an integral type and inside u64 limits.
Otherwise return Err(self).
Return the value as f32 if it’s a numeric type. Otherwise return Err(self).
Return the value as f64 if it’s a numeric type. Otherwise return Err(self).
Return the value as a byte array if it’s a string, DevEncoded or
CharArray. Otherwise return Err(self).
Return the value as a string if it’s a string, DevEncoded or CharArray,
and decodable as UTF-8. Otherwise return Err(self).